@@ -33,10 +33,9 @@
 
 namespace gdalcubes {
 
-// TODO: use a global seed and include something like process id in seed
-// to avoid conflicts when gdalcubes runs in parallel processes
 std::string utils::generate_unique_filename(uint16_t n, std::string prefix, std::string suffix) {
-    static std::mt19937 gen(time(NULL));  //Standard mersenne_twister_engine seeded with rd()
+    static std::random_device rd{};
+    static std::mt19937 gen(rd());  //Standard mersenne_twister_engine seeded with rd()
     static const std::string LETTERS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
     static std::uniform_int_distribution<> dis(0, LETTERS.length() - 1);
     static std::mutex mtx;
